Exception: UberTask::EventHandled

Inherits:
Exception
  • Object
show all
Defined in:
lib/uber_task/event_handled.rb

Overview

We are inheriting from Exception to make sure it won’t be caught by accident which would affect the flow the tasks.